@@ -267,7 +267,7 @@ def merge_gnome_path(options):
     path = path and path.split(':') or []
 
     prefix = popen(
-        'C:\msys64\clangarm64\bin/pkg-config.EXE --variable=prefix glib-2.0'
+        'C:\M\msys64\clangarm64\bin/pkg-config.EXE --variable=prefix glib-2.0'
         ).readline().rstrip()
 
     path.insert(0, prefix)
